# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2026.1.24.1] - 2026-01-24

### Added
- Initial release of MCP Serp server
- Google web search with structured results
- Image search support
- News search with time filtering
- Video search support
- Places/local business search
- Maps search support
- Knowledge graph extraction
- Answer box extraction
- People Also Ask extraction
- Related searches extraction
- Country and language localization
- Time range filtering
- Pagination support
- Comprehensive MCP prompts for LLM guidance
- Information tools for search parameters
